# TEXT DB

Documentation

Import it like this **_from textdb.manager import *_** 

To edit a file use **_manager = TextDB()_**

To read a file use **_manager.read()_**

To write to a file use **_manager.write(name_of_value, value)_**